@@ -1,6 +1,6 @@
 package App::mdee;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 1;
 =encoding utf-8
@@ -38,7 +38,7 @@ mdee - Markdown, Easy on the Eyes
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 =head1 DESCRIPTION
@@ -333,47 +333,68 @@ The overall data flow is:
 
 B<mdee> dynamically constructs a pipeline based on enabled options.
 Each stage is represented as a Bash array containing the command and
-its arguments.  The `--dryrun` option displays the constructed pipeline
+its arguments.  The C<--dryrun> option displays the constructed pipeline
 without execution.
 
 =head3 Processing Stages
 
 The pipeline consists of four configurable stages.  Each stage can be
-enabled or disabled independently using `--[no-]fold`, `--[no-]table`,
-and `--[no-]nup` options.
+enabled or disabled independently using C<--[no-]fold>, C<--[no-]table>,
+and C<--[no-]nup> options.
 
 =head4 Syntax Highlighting
 
-The first stage uses L<greple(1)> with the `-G` (grep mode) and
-`--ci=G` (capture index) options to apply different colors to each
+The first stage uses L<greple(1)> with the C<-G> (grep mode) and
+C<--ci=G> (capture index) options to apply different colors to each
 captured group in regular expressions.
 
 Supported Markdown elements:
 
-- Headers (`# h1` through `###### h6`)
-- Bold text (`**bold**` or `__bold__`)
-- Italic text (`*italic*` or `_italic_`)
-- Inline code (`` `code` ``)
-- Code blocks (fenced with ``` or ~~~)
-- HTML comments (`<!-- comment -->`)
+=over 4
+
+=item * Headers (C<# h1> through C<###### h6>)
+
+=item * Bold text (C<**bold**> or C<__bold__>)
+
+=item * Italic text (C<*italic*> or C<_italic_>)
+
+=item * Inline code (C<`code`>)
+
+=item * Code blocks (fenced with C<```> or C<~~~>)
+
+=item * HTML comments (C<< <!-- comment --> >>)
+
+=back
 
 Code block detection follows the CommonMark specification:
 
-- Opening fence: 0-3 spaces indentation, then 3+ backticks or tildes
-- Closing fence: 0-3 spaces indentation, same character, same or more count
-- Backticks and tildes cannot be mixed (``` must close with ```)
+=over 4
 
-=head5 Color Specifications
+=item * Opening fence: 0-3 spaces indentation, then 3+ backticks or tildes
+
+=item * Closing fence: 0-3 spaces indentation, same character, same or more count
+
+=item * Backticks and tildes cannot be mixed (C<```> must close with C<```>)
+
+=back
+
+B<Color Specifications>
 
 Colors are specified using L<Term::ANSIColor::Concise> format.
-The `--cm` option maps colors to captured groups.  For example,
-`L00DE/${base}` specifies gray foreground on base-colored background.
+The C<--cm> option maps colors to captured groups.  For example,
+C<L00DE/${base}> specifies gray foreground on base-colored background.
 
 The color specification supports modifiers:
 
-- `+l10` / `-l10`: Adjust lightness by percentage
-- `=l50`: Set absolute lightness
-- `D`: Bold, `U`: Underline, `E`: Erase line
+=over 4
+
+=item * C<+l10> / C<-l10>: Adjust lightness by percentage
+
+=item * C<=l50>: Set absolute lightness
+
+=item * C<D>: Bold, C<U>: Underline, C<E>: Erase line
+
+=back
 
 Example greple invocation:
 
@@ -388,18 +409,18 @@ The second stage wraps long lines in list items using L<ansifold(1)>
 via L<Greple::tee>.  It preserves ANSI escape sequences and maintains
 proper indentation for nested lists.
 
-The folding width is controlled by `--width` option (default: 80).
+The folding width is controlled by C<--width> option (default: 80).
 
 =head4 Table Formatting
 
 The third stage formats Markdown tables using L<ansicolumn(1)>.
-Tables are detected by the pattern `^(\|.+\|\n){3,}` and formatted
+Tables are detected by the pattern C<^(\|.+\|\n){3,}> and formatted
 with aligned columns while preserving ANSI colors.
 
 =head3 Output Stage
 
 The final stage uses L<nup(1)> to provide multi-column paged output.
-Layout options (`--pane`, `--row`, `--grid`, `--page`) are passed
+Layout options (C<--pane>, C<--row>, C<--grid>, C<--page>) are passed
 directly to nup.
 
 =head2 Theme System
@@ -420,7 +441,7 @@ definitions for each Markdown element:
 
 =head4 Base Color Expansion
 
-The `${base}` placeholder in color values is expanded after theme
+The C<${base}> placeholder in color values is expanded after theme
 loading.  This allows derived colors to be calculated from a single
 base color, making theme customization easier.
 
@@ -430,6 +451,37 @@ B<mdee> uses L<Getopt::EX::termcolor> to detect terminal background
 luminance.  If luminance is below 50%, dark mode is automatically
 selected.
 
+=head1 LIMITATIONS
+
+=head2 HTML Comments
+
+Only HTML comments starting at the beginning of a line are highlighted.
+Inline comments are not matched to avoid conflicts with inline code
+containing comment-like text (e.g., C<< `<!-->` >>).
+
+=head2 Emphasis
+
+Emphasis patterns (bold and italic) do not span multiple lines.
+Multi-line emphasis text is not supported.
+
+=head2 Links
+
+Link patterns do not span multiple lines.  The link text and URL must
+be on the same line.
+
+Reference-style links (C<[text][ref]> with C<[ref]: url> elsewhere)
+are not supported.
+
+=head2 OSC 8 Hyperlinks
+
+Links are converted to OSC 8 terminal hyperlinks for clickable URLs.
+This requires terminal support.  Compatible terminals include iTerm2,
+Kitty, WezTerm, Ghostty, and recent versions of GNOME Terminal.
+Apple's default Terminal.app does not support OSC 8.
+
+When using C<less> as pager, version 566 or later is required with
+C<-R> option.
+
 =head1 SEE ALSO
 
 L<nup(1)>, L<greple(1)>, L<ansifold(1)>, L<ansicolumn(1)>
